@@ -5,16 +5,16 @@ use warnings;
 use bytes;
 require Exporter ;
 
-use IO::Compress::Base 2.008 ;
+use IO::Compress::Base 2.009 ;
 
-use IO::Compress::Base::Common  2.008 qw(createSelfTiedObject);
-use IO::Compress::Adapter::Bzip2 2.008 ;
+use IO::Compress::Base::Common  2.009 qw(createSelfTiedObject);
+use IO::Compress::Adapter::Bzip2 2.009 ;
 
 
 
 our ($VERSION, @ISA, @EXPORT_OK, %EXPORT_TAGS, $Bzip2Error);
 
-$VERSION = '2.008';
+$VERSION = '2.009';
 $Bzip2Error = '';
 
 @ISA    = qw(Exporter IO::Compress::Base);
@@ -51,7 +51,7 @@ sub getExtraParams
 {
     my $self = shift ;
 
-    use IO::Compress::Base::Common  2.008 qw(:Parse);
+    use IO::Compress::Base::Common  2.009 qw(:Parse);
     
     return (
             'BlockSize100K' => [0, 1, Parse_unsigned,  1],
@@ -143,8 +143,6 @@ __END__
 
 =head1 NAME
 
-
-
 IO::Compress::Bzip2 - Write bzip2 files/buffers
  
  
@@ -153,7 +151,6 @@ IO::Compress::Bzip2 - Write bzip2 files/buffers
 
     use IO::Compress::Bzip2 qw(bzip2 $Bzip2Error) ;
 
-
     my $status = bzip2 $input => $output [,OPTS] 
         or die "bzip2 failed: $Bzip2Error\n";
 
@@ -193,24 +190,12 @@ IO::Compress::Bzip2 - Write bzip2 files/buffers
 
 =head1 DESCRIPTION
 
-
 This module provides a Perl interface that allows writing bzip2 
 compressed data to files or buffer.
 
-
-
-
-
-
-
-
-
-
-
 For reading bzip2 files/buffers, see the companion module 
 L<IO::Uncompress::Bunzip2|IO::Uncompress::Bunzip2>.
 
-
 =head1 Functional Interface
 
 A top-level function, C<bzip2>, is provided to carry out
@@ -223,14 +208,10 @@ section.
     bzip2 $input => $output [,OPTS] 
         or die "bzip2 failed: $Bzip2Error\n";
 
-
-
 The functional interface needs Perl5.005 or better.
 
-
 =head2 bzip2 $input => $output [, OPTS]
 
-
 C<bzip2> expects at least two parameters, C<$input> and C<$output>.
 
 =head3 The C<$input> parameter
@@ -269,8 +250,6 @@ The input data will be read from each file in turn.
 The complete array will be walked to ensure that it only
 contains valid filenames before any data is compressed.
 
-
-
 =item An Input FileGlob string
 
 If C<$input> is a string that is delimited by the characters "<" and ">"
@@ -281,13 +260,10 @@ If the fileglob does not match any files ...
 
 See L<File::GlobMapper|File::GlobMapper> for more details.
 
-
 =back
 
 If the C<$input> parameter is any other type, C<undef> will be returned.
 
-
-
 =head3 The C<$output> parameter
 
 The parameter C<$output> is used to control the destination of the
@@ -307,14 +283,11 @@ If the C<$output> parameter is a filehandle, the compressed data
 will be written to it.
 The string '-' can be used as an alias for standard output.
 
-
 =item A scalar reference 
 
 If C<$output> is a scalar reference, the compressed data will be
 stored in C<$$output>.
 
-
-
 =item An Array Reference
 
 If C<$output> is an array reference, the compressed data will be
@@ -333,21 +306,12 @@ string. Anything else is an error.
 
 If the C<$output> parameter is any other type, C<undef> will be returned.
 
-
-
 =head2 Notes
 
-
-
 When C<$input> maps to multiple files/buffers and C<$output> is a single
 file/buffer the input files/buffers will be stored
 in C<$output> as a concatenated series of compressed data streams.
 
-
-
-
-
-
 =head2 Optional Parameters
 
 Unless specified below, the optional parameters for C<bzip2>,
@@ -367,27 +331,18 @@ completed.
 
 This parameter defaults to 0.
 
-
 =item C<< BinModeIn => 0|1 >>
 
 When reading from a file or filehandle, set C<binmode> before reading.
 
 Defaults to 0.
 
-
-
-
-
 =item C<< Append => 0|1 >>
 
 TODO
 
-
-
 =back
 
-
-
 =head2 Examples
 
 To read the contents of the file C<file1.txt> and write the compressed
@@ -401,7 +356,6 @@ data to the file C<file1.txt.bz2>.
     bzip2 $input => "$input.bz2"
         or die "bzip2 failed: $Bzip2Error\n";
 
-
 To read from an existing Perl filehandle, C<$input>, and write the
 compressed data to a buffer, C<$buffer>.
 
@@ -439,7 +393,6 @@ and if you want to compress each file one at a time, this will do the trick
             or die "Error compressing '$input': $Bzip2Error\n";
     }
 
-
 =head1 OO Interface
 
 =head2 Constructor
@@ -479,7 +432,6 @@ If the C<$output> parameter is a filehandle, the compressed data will be
 written to it.
 The string '-' can be used as an alias for standard output.
 
-
 =item A scalar reference 
 
 If C<$output> is a scalar reference, the compressed data will be stored
@@ -535,7 +487,6 @@ to it.  Otherwise the file pointer will not be moved.
 
 This parameter defaults to 0.
 
-
 =item C<< BlockSize100K => number >>
 
 Specify the number of 100K blocks bzip2 uses during compression. 
@@ -553,22 +504,10 @@ Valid values range from 0 to 250, where 0 means use the default value 30.
 
 The default is 0.
 
-
-
-
-
-
-
-
-
 =item C<< Strict => 0|1 >>
 
-
-
 This is a placeholder option.
 
-
-
 =back
 
 =head2 Examples
@@ -630,19 +569,14 @@ unsuccessful.
 
 Usage is
 
-
     $z->flush;
 
-
 Flushes any pending compressed data to the output file/buffer.
 
-
 TODO
 
-
 Returns true on success.
 
-
 =head2 tell
 
 Usage is
@@ -659,28 +593,19 @@ Usage is
     $z->eof();
     eof($z);
 
-
-
 Returns true if the C<close> method has been called.
 
-
-
 =head2 seek
 
     $z->seek($position, $whence);
     seek($z, $position, $whence);
 
-
-
-
 Provides a sub-set of the C<seek> functionality, with the restriction
 that it is only legal to seek forward in the output file/buffer.
 It is a fatal error to attempt to seek backward.
 
 Empty parts of the file/buffer will have NULL (0x00) bytes written to them.
 
-
-
 The C<$whence> parameter takes one the usual values, namely SEEK_SET,
 SEEK_CUR or SEEK_END.
 
@@ -722,33 +647,27 @@ retrieve the autoflush setting.
     $z->input_line_number()
     $z->input_line_number(EXPR)
 
-
 This method always returns C<undef> when compressing. 
 
-
-
 =head2 fileno
 
     $z->fileno()
     fileno($z)
 
-If the C<$z> object is associated with a file or a filehandle, this method
-will return the underlying file descriptor.
+If the C<$z> object is associated with a file or a filehandle, C<fileno>
+will return the underlying file descriptor. Once the C<close> method is
+called C<fileno> will return C<undef>.
 
-If the C<$z> object is is associated with a buffer, this method will
-return undef.
+If the C<$z> object is is associated with a buffer, this method will return
+C<undef>.
 
 =head2 close
 
     $z->close() ;
     close $z ;
 
-
-
 Flushes any pending compressed data and then closes the output file/buffer. 
 
-
-
 For most versions of Perl this method will be automatically invoked if
 the IO::Compress::Bzip2 object is destroyed (either explicitly or by the
 variable with the reference to the object going out of scope). The
@@ -767,9 +686,6 @@ If the C<AutoClose> option has been enabled when the IO::Compress::Bzip2
 object was created, and the object is associated with a file, the
 underlying file will also be closed.
 
-
-
-
 =head2 newStream([OPTS])
 
 Usage is
@@ -783,20 +699,14 @@ the C<$z> object.
 
 See the L</"Constructor Options"> section for more details.
 
-
-
 =head1 Importing 
 
-
 No symbolic constants are required by this IO::Compress::Bzip2 at present. 
 
-
-
 =over 5
 
 =item :all
 
-
 Imports C<bzip2> and C<$Bzip2Error>.
 Same as doing this
 
@@ -806,21 +716,17 @@ Same as doing this
 
 =back
 
-For 
-
 =head1 EXAMPLES
 
-TODO
-
-
-
-
-
-
+=head2 Apache::GZip Revisited
 
+See L<IO::Compress::Bzip2::FAQ|IO::Compress::Bzip2::FAQ/"Apache::GZip Revisited">
 
+    
 
+=head2 Working with Net::FTP
 
+See L<IO::Compress::Bzip2::FAQ|IO::Compress::Bzip2::FAQ/"Compressed files and Net::FTP">
 
 =head1 SEE ALSO
 
@@ -832,29 +738,22 @@ L<File::GlobMapper|File::GlobMapper>, L<Archive::Zip|Archive::Zip>,
 L<Archive::Tar|Archive::Tar>,
 L<IO::Zlib|IO::Zlib>
 
-
-
 The primary site for the bzip2 program is F<http://www.bzip.org>.
 
 See the module L<Compress::Bzip2|Compress::Bzip2>
 
-
-
 =head1 AUTHOR
 
 This module was written by Paul Marquess, F<pmqs@cpan.org>. 
 
-
-
 =head1 MODIFICATION HISTORY
 
 See the Changes file.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2005-2007 Paul Marquess. All rights reserved.
+Copyright (c) 2005-2008 Paul Marquess. All rights reserved.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
-
