@@ -4,15 +4,15 @@ use strict ;
 use warnings;
 use bytes;
 
-use IO::Compress::Base::Common 2.008 qw(:Status createSelfTiedObject);
+use IO::Compress::Base::Common 2.009 qw(:Status createSelfTiedObject);
 
-use IO::Uncompress::Base 2.008 ;
-use IO::Uncompress::Adapter::Bunzip2 2.008 ;
+use IO::Uncompress::Base 2.009 ;
+use IO::Uncompress::Adapter::Bunzip2 2.009 ;
 
 require Exporter ;
 our ($VERSION, @ISA, @EXPORT_OK, %EXPORT_TAGS, $Bunzip2Error);
 
-$VERSION = '2.008';
+$VERSION = '2.009';
 $Bunzip2Error = '';
 
 @ISA    = qw( Exporter IO::Uncompress::Base );
@@ -40,7 +40,7 @@ sub getExtraParams
 {
     my $self = shift ;
 
-    use IO::Compress::Base::Common 2.008 qw(:Parse);
+    use IO::Compress::Base::Common 2.009 qw(:Parse);
     
     return (
             'Verbosity'     => [1, 1, Parse_boolean,   0],
@@ -145,12 +145,8 @@ __END__
 
 =head1 NAME
 
-
-
 IO::Uncompress::Bunzip2 - Read bzip2 files/buffers
 
-
-
 =head1 SYNOPSIS
 
     use IO::Uncompress::Bunzip2 qw(bunzip2 $Bunzip2Error) ;
@@ -194,20 +190,13 @@ IO::Uncompress::Bunzip2 - Read bzip2 files/buffers
     eof($z)
     close($z)
 
-
 =head1 DESCRIPTION
 
-
-
 This module provides a Perl interface that allows the reading of
 bzip2 files/buffers.
 
 For writing bzip2 files/buffers, see the companion module IO::Compress::Bzip2.
 
-
-
-
-
 =head1 Functional Interface
 
 A top-level function, C<bunzip2>, is provided to carry out
@@ -220,14 +209,10 @@ section.
     bunzip2 $input => $output [,OPTS] 
         or die "bunzip2 failed: $Bunzip2Error\n";
 
-
-
 The functional interface needs Perl5.005 or better.
 
-
 =head2 bunzip2 $input => $output [, OPTS]
 
-
 C<bunzip2> expects at least two parameters, C<$input> and C<$output>.
 
 =head3 The C<$input> parameter
@@ -266,8 +251,6 @@ The input data will be read from each file in turn.
 The complete array will be walked to ensure that it only
 contains valid filenames before any data is uncompressed.
 
-
-
 =item An Input FileGlob string
 
 If C<$input> is a string that is delimited by the characters "<" and ">"
@@ -278,13 +261,10 @@ If the fileglob does not match any files ...
 
 See L<File::GlobMapper|File::GlobMapper> for more details.
 
-
 =back
 
 If the C<$input> parameter is any other type, C<undef> will be returned.
 
-
-
 =head3 The C<$output> parameter
 
 The parameter C<$output> is used to control the destination of the
@@ -304,14 +284,11 @@ If the C<$output> parameter is a filehandle, the uncompressed data
 will be written to it.
 The string '-' can be used as an alias for standard output.
 
-
 =item A scalar reference 
 
 If C<$output> is a scalar reference, the uncompressed data will be
 stored in C<$$output>.
 
-
-
 =item An Array Reference
 
 If C<$output> is an array reference, the uncompressed data will be
@@ -330,20 +307,13 @@ string. Anything else is an error.
 
 If the C<$output> parameter is any other type, C<undef> will be returned.
 
-
-
 =head2 Notes
 
-
 When C<$input> maps to multiple compressed files/buffers and C<$output> is
 a single file/buffer, after uncompression C<$output> will contain a
 concatenation of all the uncompressed data from each of the input
 files/buffers.
 
-
-
-
-
 =head2 Optional Parameters
 
 Unless specified below, the optional parameters for C<bunzip2>,
@@ -363,7 +333,6 @@ completed.
 
 This parameter defaults to 0.
 
-
 =item C<< BinModeOut => 0|1 >>
 
 When writing to a file or filehandle, set C<binmode> before writing to the
@@ -371,26 +340,17 @@ file.
 
 Defaults to 0.
 
-
-
-
-
 =item C<< Append => 0|1 >>
 
 TODO
 
 =item C<< MultiStream => 0|1 >>
 
-
 If the input file/buffer contains multiple compressed data streams, this
 option will uncompress the whole lot as a single data stream.
 
 Defaults to 0.
 
-
-
-
-
 =item C<< TrailingData => $scalar >>
 
 Returns the data, if any, that is present immediately after the compressed
@@ -410,19 +370,12 @@ of the input file.
 
 Don't bother using C<trailingData> if the input is a filename.
 
-
-
 If you know the length of the compressed data stream before you start
 uncompressing, you can avoid having to use C<trailingData> by setting the
 C<InputLength> option.
 
-
-
 =back
 
-
-
-
 =head2 Examples
 
 To read the contents of the file C<file1.txt.bz2> and write the
@@ -437,7 +390,6 @@ compressed data to the file C<file1.txt>.
     bunzip2 $input => $output
         or die "bunzip2 failed: $Bunzip2Error\n";
 
-
 To read from an existing Perl filehandle, C<$input>, and write the
 uncompressed data to a buffer, C<$buffer>.
 
@@ -481,7 +433,6 @@ and if you want to compress each file one at a time, this will do the trick
 
 The format of the constructor for IO::Uncompress::Bunzip2 is shown below
 
-
     my $z = new IO::Uncompress::Bunzip2 $input [OPTS]
         or die "IO::Uncompress::Bunzip2 failed: $Bunzip2Error\n";
 
@@ -513,7 +464,6 @@ If the C<$input> parameter is a filehandle, the compressed data will be
 read from it.
 The string '-' can be used as an alias for standard input.
 
-
 =item A scalar reference 
 
 If C<$input> is a scalar reference, the compressed data will be read from
@@ -523,7 +473,6 @@ C<$$output>.
 
 =head2 Constructor Options
 
-
 The option names defined below are case insensitive and can be optionally
 prefixed by a '-'.  So all of the following are valid
 
@@ -547,8 +496,6 @@ This parameter defaults to 0.
 
 =item C<< MultiStream => 0|1 >>
 
-
-
 Allows multiple concatenated compressed streams to be treated as a single
 compressed stream. Decompression will stop once either the end of the
 file/buffer is reached, an error is encountered (premature eof, corrupt
@@ -557,7 +504,6 @@ start of another stream.
 
 This parameter defaults to 0.
 
-
 =item C<< Prime => $string >>
 
 This option will uncompress the contents of C<$string> before processing the
@@ -599,8 +545,6 @@ This option is mostly used when reading from a filehandle, in which case
 the file pointer will be left pointing to the first byte directly after the
 compressed data stream.
 
-
-
 This option defaults to off.
 
 =item C<< Append => 0|1 >>
@@ -617,16 +561,8 @@ Defaults to 0.
 
 =item C<< Strict => 0|1 >>
 
-
-
 This option is a no-op.
 
-
-
-
-
-
-
 =item C<< Small => 0|1 >>
 
 When non-zero this options will make bzip2 use a decompression algorithm
@@ -635,7 +571,6 @@ taken for decompression.
 
 Default is 0.
 
-
 =back
 
 =head2 Examples
@@ -679,7 +614,6 @@ or an IO error is encountered.
 Returns the number of uncompressed bytes written to C<$buffer>, zero if eof
 or a negative number on error.
 
-
 =head2 getline
 
 Usage is
@@ -694,7 +628,6 @@ C<$INPUT_RECORD_SEPARATOR> or C<$RS> when C<English> is in use) to
 determine what constitutes an end of line. Paragraph mode, record mode and
 file slurp mode are all supported. 
 
-
 =head2 getc
 
 Usage is 
@@ -709,9 +642,6 @@ Usage is
 
     $char = $z->ungetc($string)
 
-
-
-
 =head2 getHeaderInfo
 
 Usage is
@@ -723,9 +653,6 @@ This method returns either a hash reference (in scalar context) or a list
 or hash references (in array context) that contains information about each
 of the header fields in the compressed data stream(s).
 
-
-
-
 =head2 tell
 
 Usage is
@@ -742,26 +669,17 @@ Usage is
     $z->eof();
     eof($z);
 
-
-
 Returns true if the end of the compressed input stream has been reached.
 
-
-
 =head2 seek
 
     $z->seek($position, $whence);
     seek($z, $position, $whence);
 
-
-
-
 Provides a sub-set of the C<seek> functionality, with the restriction
 that it is only legal to seek forward in the input file/buffer.
 It is a fatal error to attempt to seek backward.
 
-
-
 The C<$whence> parameter takes one the usual values, namely SEEK_SET,
 SEEK_CUR or SEEK_END.
 
@@ -803,8 +721,6 @@ retrieve the autoflush setting.
     $z->input_line_number()
     $z->input_line_number(EXPR)
 
-
-
 Returns the current uncompressed line number. If C<EXPR> is present it has
 the effect of setting the line number. Note that setting the line number
 does not change the current position within the file/buffer being read.
@@ -812,30 +728,25 @@ does not change the current position within the file/buffer being read.
 The contents of C<$/> are used to to determine what constitutes a line
 terminator.
 
-
-
 =head2 fileno
 
     $z->fileno()
     fileno($z)
 
-If the C<$z> object is associated with a file or a filehandle, this method
-will return the underlying file descriptor.
+If the C<$z> object is associated with a file or a filehandle, C<fileno>
+will return the underlying file descriptor. Once the C<close> method is
+called C<fileno> will return C<undef>.
 
-If the C<$z> object is is associated with a buffer, this method will
-return undef.
+If the C<$z> object is is associated with a buffer, this method will return
+C<undef>.
 
 =head2 close
 
     $z->close() ;
     close $z ;
 
-
-
 Closes the output file/buffer. 
 
-
-
 For most versions of Perl this method will be automatically invoked if
 the IO::Uncompress::Bunzip2 object is destroyed (either explicitly or by the
 variable with the reference to the object going out of scope). The
@@ -854,9 +765,6 @@ If the C<AutoClose> option has been enabled when the IO::Uncompress::Bunzip2
 object was created, and the object is associated with a file, the
 underlying file will also be closed.
 
-
-
-
 =head2 nextStream
 
 Usage is
@@ -895,8 +803,6 @@ of the input file.
 
 Don't bother using C<trailingData> if the input is a filename.
 
-
-
 If you know the length of the compressed data stream before you start
 uncompressing, you can avoid having to use C<trailingData> by setting the
 C<InputLength> option in the constructor.
@@ -918,8 +824,9 @@ Same as doing this
 
 =head1 EXAMPLES
 
+=head2 Working with Net::FTP
 
-
+See L<IO::Uncompress::Bunzip2::FAQ|IO::Uncompress::Bunzip2::FAQ/"Compressed files and Net::FTP">
 
 =head1 SEE ALSO
 
@@ -931,27 +838,21 @@ L<File::GlobMapper|File::GlobMapper>, L<Archive::Zip|Archive::Zip>,
 L<Archive::Tar|Archive::Tar>,
 L<IO::Zlib|IO::Zlib>
 
-
-
 The primary site for the bzip2 program is F<http://www.bzip.org>.
 
 See the module L<Compress::Bzip2|Compress::Bzip2>
 
-
-
 =head1 AUTHOR
 
 This module was written by Paul Marquess, F<pmqs@cpan.org>. 
 
-
-
 =head1 MODIFICATION HISTORY
 
 See the Changes file.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2005-2007 Paul Marquess. All rights reserved.
+Copyright (c) 2005-2008 Paul Marquess. All rights reserved.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
